#include <stdio.h>
#include <math.h>
#include <stdlib.h> // for rand, system

//////////////////////////////////////////////////////////////////
//				Euler solver for pandemic model (SIR):  		//
//////////////////////////////////////////////////////////////////
// Free to use, improve, and redistribute. No commercial use.   //
// Created by Niels Benedikter. Please keep this document head. //
// Feel free to add your name if you make modifications.		//
//////////////////////////////////////////////////////////////////


int main (void)
{
	// prepare the file to collect the output
 	FILE* file1 = fopen("infettati.dat", "wt");
    if (file1 == NULL)  {
        printf("Problem: File infetatti.dat could not be created!\n");
       	return(1);
    }

 	FILE* file2 = fopen("guariti.dat", "wt");
    if (file2 == NULL)  {
        printf("Problem: File guariti.dat could not be created!\n");
       	return(1);
    }

	printf("CORONA: Euler method solving a SIR epidemiological model.\n");
	printf("Total population: 60 million people (Italy). Initial infections: 1.\n");

    // physical constants
    double BETA;
    double RZERO;
    double GAMMA = (double) 1/14;
    double NTOTAL = (double) 60000000;   // 60 million inhabitants

    //algorithm constants
    double DT = (double) 1;         // time step (DT = 1 means 1 day)
    int TMAX = 1000;                 // simulation duration

    double I, G;
    I = (double) 1; G = (double) 0;

    printf("base reproduction number Rzero = ? (e.g., 0.5, 1.1, 3) ");
    scanf("%lf", &RZERO);
    BETA = RZERO*GAMMA;

    int steps = (int) (TMAX / DT);
	for (int i =0; i < steps; i++) {
        I = I + DT*(  BETA*I*(1 - ((I + G)/NTOTAL)) - GAMMA*I  );
        G = G + DT*(  GAMMA*I  );		
        
    	fprintf(file1,"%.10lf\n", I);
        fprintf(file2,"%.10lf\n", G);
		}

	fclose(file1);
    fclose(file2);

//	char d;
//	printf("Run gnuplot to show simulation? (y=yes,other=no)");
//	scanf("%c",&d);
//	if (d=='y') {
		system("gnuplot -p 'script.gp'");
//	}

	return 0;
}
